@@ -42,7 +42,7 @@ functions, seeing and atmospheric conditions.
 """
 
 
-__version__ = "2.4.2"
+__version__ = "2.5.1"
 
 __all__ = [
     "MIN_MATCHES_FRACTION",
@@ -73,6 +73,7 @@ def estimate_transform(*args, **kwargs):
     https://scikit-image.org/docs/stable/api/skimage.transform.html#skimage.transform.estimate_transform
     """
     from skimage.transform import estimate_transform
+
     return estimate_transform(*args, **kwargs)
 
 
@@ -83,6 +84,7 @@ def matrix_transform(*args, **kwargs):
     https://scikit-image.org/docs/stable/api/skimage.transform.html#skimage.transform.matrix_transform
     """
     from skimage.transform import matrix_transform
+
     return matrix_transform(*args, **kwargs)
 
 
@@ -247,10 +249,21 @@ class _MatchTransform:
 
 
 def _data(image):
+    """Return the bare 2D numpy array with pixel information."""
     if hasattr(image, "data") and isinstance(image.data, _np.ndarray):
         return image.data
-    else:
-        return _np.asarray(image)
+    return _np.asarray(image)
+
+
+def _mask(image):
+    """Return a 2D numpy mask array if any, or None if there is no mask."""
+    if hasattr(image, "mask"):
+        the_np_mask = _np.asarray(image.mask)
+        if the_np_mask.ndim == 2:
+            return the_np_mask
+        else:
+            return _np.logical_or.reduce(the_np_mask, axis=-1)
+    return None
 
 
 def _bw(image):
@@ -322,6 +335,7 @@ def find_transform(
                 _bw(_data(source)),
                 detection_sigma=detection_sigma,
                 min_area=min_area,
+                mask=_mask(source),
             )[:max_control_points]
     except Exception:
         raise TypeError("Input type for source not supported.")
@@ -336,6 +350,7 @@ def find_transform(
                 _bw(_data(target)),
                 detection_sigma=detection_sigma,
                 min_area=min_area,
+                mask=_mask(target),
             )[:max_control_points]
     except Exception:
         raise TypeError("Input type for target not supported.")
@@ -469,8 +484,8 @@ def apply_transform(
     )
     footprint = footprint > 0.4
 
-    if hasattr(source, "mask") and propagate_mask:
-        source_mask = _np.array(source.mask)
+    source_mask = _mask(source)
+    if source_mask is not None and propagate_mask:
         if source_mask.shape == source_data.shape:
             source_mask_rot = warp(
                 source_mask.astype("float32"),
@@ -544,17 +559,16 @@ def register(
     return aligned_image, footprint
 
 
-def _find_sources(img, detection_sigma=5, min_area=5):
+def _find_sources(img, detection_sigma=5, min_area=5, mask=None):
     """Return sources (x, y) sorted by brightness."""
     import sep
 
-    if isinstance(img, _np.ma.MaskedArray):
-        image = img.filled(fill_value=_default_median(img)).astype("float32")
-    else:
-        image = img.astype("float32")
-    bkg = sep.Background(image)
+    image = img.astype("float32")
+    bkg = sep.Background(image, mask=mask)
     thresh = detection_sigma * bkg.globalrms
-    sources = sep.extract(image - bkg.back(), thresh, minarea=min_area)
+    sources = sep.extract(
+        image - bkg.back(), thresh, minarea=min_area, mask=mask
+    )
     sources.sort(order="flux")
     return _np.array([[asrc["x"], asrc["y"]] for asrc in sources[::-1]])
 
@@ -620,7 +634,7 @@ def _ransac(data, model, thresh, min_matches):
     good_fit = None
     n_data = data.shape[0]
     all_idxs = _np.arange(n_data)
-    _np.random.shuffle(all_idxs)
+    _np.random.default_rng().shuffle(all_idxs)
 
     for iter_i in range(n_data):
         # Partition indices into two random subsets
